summaryrefslogtreecommitdiffstats
path: root/snaps/openstack/create_stack.py
diff options
context:
space:
mode:
authorspisarski <s.pisarski@cablelabs.com>2017-11-17 08:35:45 -0700
committerspisarski <s.pisarski@cablelabs.com>2017-11-20 07:43:34 -0700
commit88c180252d78226e06ecf53a23d4f0eca9815bb8 (patch)
treed448f86a7c3f15cc5d255054465ff9b1f67967c6 /snaps/openstack/create_stack.py
parentf9d332f6c67f5e0cb70c1570499996926ffbdf5c (diff)
Refactoring of KeypairSettings to extend KeypairConfig
KeypairSettings and glance_utils have a runtime cyclical dependency. This patch reduces this dependency and deprecates the KeypairSettings class. JIRA: SNAPS-219 Change-Id: I92f51ecb77238444697e922c8f089e78d1c643aa Signed-off-by: spisarski <s.pisarski@cablelabs.com>
Diffstat (limited to 'snaps/openstack/create_stack.py')
-rw-r--r--snaps/openstack/create_stack.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/snaps/openstack/create_stack.py b/snaps/openstack/create_stack.py
index aebe52a..4ed293d 100644
--- a/snaps/openstack/create_stack.py
+++ b/snaps/openstack/create_stack.py
@@ -58,7 +58,7 @@ class OpenStackHeatStack(OpenStackCloudObject, object):
:param stack_settings: The stack settings
:param image_settings: A list of ImageConfig objects that were used
for spawning this stack
:param keypair_settings: A list of KeypairSettings objects that were
used for spawning this stack
:return:
"""
@@ -299,7 +299,7 @@ class OpenStackHeatStack(OpenStackCloudObject, object):
nova, neutron, stack_server)
image_settings = settings_utils.determine_image_config(
glance, stack_server, self.image_settings)
- keypair_settings = settings_utils.determine_keypair_settings(
+ keypair_settings = settings_utils.determine_keypair_config(
self.__heat_cli, self.__stack, stack_server,
keypair_settings=self.keypair_settings,
priv_key_key=heat_keypair_option)
@@ -58,7 +58,7 @@ class OpenStackHeatStack(OpenStackCloudObject, object):
:param image_settings: A list of ImageConfig objects that were used
for spawning this stack
- :param keypair_settings: A list of KeypairSettings objects that were
+ :param keypair_settings: A list of KeypairConfig objects that were
used for spawning this stack
:return: